@@ -22,6 +22,9 @@ class WebCompressor:
     Supercharges HTML files & web assets
     """
 
+    # HTML files & web assets to be ignored
+    block_list: List[str] = []
+
     def __init__(self, base_dir: Union[Path, str], **kwargs) -> None:
         """
         Constructor
@@ -56,7 +59,10 @@ class WebCompressor:
         # (2) .. hidden files
         # (2) .. anything below '.well-known'
         return not (
-            file.is_dir() or file.stem.startswith(".") or ".well-known" in file.parts
+            file.is_dir()
+            or file.stem.startswith(".")
+            or ".well-known" in file.parts
+            or file.name in self.block_list
         )
 
         # NOTE:
