@@ -14,7 +14,7 @@ class Handler(metaclass=abc.ABCMeta):
     """
 
     # Validation rules
-    ruleset: Union[re.Pattern, List[str]]
+    ruleset: Union[re.Pattern, List[str], None] = None
 
     @abc.abstractmethod
     def is_ready(self) -> bool:
