@@ -13,7 +13,7 @@ try:
 except ModuleNotFoundError:
     pass
 
-from ..utils import append2file, is_loaded
+from ..utils import append2file, get_mime, is_loaded
 from .handler import Handler
 
 
@@ -30,13 +30,17 @@ class Minifier(Handler):
             # HTML
             (?:text\/html)|
             # JS
+            # NOTE: "application/x-ecmascript" & "application/x-javascript"
+            # are deprecated (but supported). Also "text/javascript" is valid
+            # while "text/ecmascript" is not
             (?:(?:application|text)/(x-)?(?:java|ecma)script)|
             # JSON
-            (?:[a-z]*\/(?:[a-z]*-)?json)|
+            # NOTE: "text/json" is deprecated (but supported)
+            (?:(?:application|text)\/(?:ld\+)?json)|
             # SVG
             (?:image\/svg\+xml)|
             # XML
-            (?:[a-z]*\/(?:[a-z]*-)?xml)
+            (?:.*\/(?:.*\+)?xml)
         """,
         re.VERBOSE,
     )
@@ -93,23 +97,29 @@ class Minifier(Handler):
 
         return is_loaded("minify")
 
-    def minify_file(self, file: Path, mime_type: str) -> Path:
+    def minify_file(self, file: Path, mime_type: Optional[str] = None) -> Path:
         """
         Minifies single file
 
         :param file: pathlib.Path Path to file
-        :param mime_type: str Mediatype
+        :param mime_type: str | None Mediatype
         :return: pathlib.Path File
         """
 
-        # If file was minified before ..
+        # Skip files if they ..
+        # (1) .. do not exist ..
+        # (2) .. were minified before ..
         if ".min." in file.name:
-            # .. no action needed
             return file
 
         # Define temporary file
         minified = append2file(file, "min")
 
+        # If mediatype unknown ..
+        if mime_type is None:
+            # .. detect it
+            mime_type = get_mime(file.name)
+
         # Minify file contents & store in new file
         minify.file(mime_type, str(file), str(minified))
 
