@@ -5,7 +5,7 @@ which is released under GPL-3.0-only license.
 
 from pathlib import Path
 import re
-from typing import Any, Dict, List, Tuple, Union
+from typing import List, Optional, Tuple, Union
 
 try:
     import PIL as Pillow
@@ -14,7 +14,7 @@ try:
 except ModuleNotFoundError:
     pass
 
-from ..utils import append2file, is_loaded
+from ..utils import append2file, get_mime, is_loaded
 from .handler import Handler
 
 
@@ -59,27 +59,49 @@ class Optimizer(Handler):
         return is_loaded(["PIL", "pillow_avif"])
 
     def optimize_image(
-        self, file: Path, mime_type: str, quality: Union[int, str] = "keep"
+        self,
+        file: Path,
+        mime_type: Optional[str] = None,
+        quality: Union[int, str] = "keep",
+        strip_meta: bool = True,
     ) -> Path:
         """
         Optimizes single image
 
         :param file: pathlib.Path Path to Image
-        :param mime_type: str Mediatype
+        :param mime_type: str | None Mediatype
         :param quality: int | str Image quality (JPEG only)
+        :param strip_meta: bool Whether to strip EXIF metadata (experimental)
         :return: pathlib.Path Image
         """
 
-        # If file was optimized before ..
-        if ".min." in file.name:
-            # .. no action needed
+        # Skip files if they
+        # (1) .. do not exist ..
+        # (2) .. were optimized before ..
+        if not file.exists() or ".min." in file.name:
             return file
 
         # Define temporary file
         optimized = append2file(file, "min")
 
-        # Load image data
+        # Load image
         image = Pillow.Image.open(file)
+        # If specified ..
+        if strip_meta:
+            # .. strip metadata by ..
+            # (1) .. extracting image data
+            data, img_format = list(image.getdata()), image.format
+            # (2) .. creating blank canvas
+            image = Pillow.Image.new(image.mode, image.size)
+            # (3) .. inserting image data (w/o EXIF)
+            image.putdata(data)
+            # (4) .. reapplying original format
+            image.format = img_format
+
+        # If mediatype unknown ..
+        if mime_type is None:
+            # .. detect it
+            mime_type = get_mime(file.name)
 
         # If mediatype is
         # (1) .. PNG ..
@@ -89,16 +111,19 @@ class Optimizer(Handler):
 
         # (2) .. JPEG ..
         if mime_type == "image/jpeg":
-            # .. determine quality setting ('CMYK' cannot 'keep' former quality)
-            if quality == "keep" and image.mode == "CMYK":
-                quality = 100
+            # If not RGB mode ..
+            if image.mode != "RGB":
+                # .. convert it
+                image = image.convert("RGB")
+                # .. apply JPEG format
+                image.format = "JPEG"
 
             # .. optimize it
             # (a) .. making it progressive
             # (b) .. at maximum quality
             # (c) .. stripping metadata
             # (d) .. setting chroma subsampling mode to '420'
-            image.convert("RGB").save(
+            image.save(
                 optimized,
                 format="JPEG",
                 quality=quality,
@@ -110,12 +135,12 @@ class Optimizer(Handler):
         # Close file pointer
         image.close()
 
-        # Rename file
-        return file.rename(optimized)
+        # Remove original file
+        file.unlink()
 
-    def convert_image(
-        self, file: Path, avif: Dict[str, Any] = None, webp: Dict[str, Any] = None
-    ) -> Tuple[Path]:
+        return optimized
+
+    def convert_image(self, file: Path, **kwargs) -> Tuple[Path]:
         """
         Converts single image to AVIF & WebP
 
@@ -129,22 +154,20 @@ class Optimizer(Handler):
         """
 
         # Load image data
-        image = Pillow.Image.open(file)
+        with Pillow.Image.open(file) as image:
+            # Create optimized AVIF image
+            # See https://pypi.org/project/pillow-avif-plugin
+            avif_file = file.with_suffix(".avif")
 
-        # Create optimized AVIF image
-        # See https://pypi.org/project/pillow-avif-plugin
-        avif_file = file.with_suffix(".avif")
+            # Apply image quality & save file
+            image.save(
+                avif_file, format="AVIF", avif=kwargs.get("avif", {"quality": 90})
+            )
 
-        # Apply image quality & save file
-        image.save(avif_file, format="AVIF", avif=avif or {"quality": 90})
+            # Create optimized WebP image
+            webp_file = file.with_suffix(".webp")
 
-        # Create optimized WebP image
-        webp_file = file.with_suffix(".webp")
-
-        # Apply compression level & save file
-        image.save(webp_file, format="WebP", webp=webp or {"method": 6})
-
-        # Close file pointer
-        image.close()
+            # Apply compression level & save file
+            image.save(webp_file, format="WebP", webp=kwargs.get("webp", {"method": 6}))
 
         return avif_file, webp_file
